| Title: | Rolling and Expanding Statistics Presentation |
|---|---|
| Description: | Presentation of rolling and expanding statistics for time-series data. The 'rolltalk' package demonstrates the rolling and expanding statistics of the 'roll' package in a 'Quarto' presentation that is rendered to a PDF file with the roll_talk() function. |
| Authors: | Jason Foster [aut, cre] |
| Maintainer: | Jason Foster <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0.0 |
| Built: | 2026-06-08 00:12:19 UTC |
| Source: | https://github.com/jasonjfoster/rolltalk |
Presentation of rolling and expanding statistics for time-series data. The 'rolltalk' package demonstrates the rolling and expanding statistics of the 'roll' package in a 'Quarto' presentation that is rendered to a PDF file with the roll_talk() function.
rolltalk is a package that provides a presentation of rolling and expanding statistics for time-series data.
Jason Foster [aut, cre]
A data set with the benchmark results for rolling statistics with a width of 100.
bench_100bench_100
A data frame. Rows are evaluation times and columns are the functions.
A data set with the benchmark results for rolling statistics with a width of 1,000.
bench_1000bench_1000
A data frame. Rows are evaluation times and columns are the functions.
A presentation for rolling and expanding statistics of time-series data.
roll_talk(output_dir = getwd(), output_file = "roll_talk.pdf", ...)roll_talk(output_dir = getwd(), output_file = "roll_talk.pdf", ...)
output_dir |
Directory for the rendered PDF file. |
output_file |
Name of the rendered PDF file. |
... |
Additional arguments passed to |
A PDF file at file.path(output_dir, output_file) with the rolling and expanding statistics presentation.
## Not run: # rolling and expanding statistics presentation roll_talk() ## End(Not run)## Not run: # rolling and expanding statistics presentation roll_talk() ## End(Not run)